@@ -3,20 +3,20 @@
 
 TCustomTreeView::TCustomTreeView(TComponent *AOwner) :
 	TWinControl(AOwner),
-	Items(this, &getItems, &SetTreeNodes),
-	Images(this, &getImages, &SetImages),
-	StateImages(this, &getStateImages, &SetStateImages),
-	Selected(this, &GetSelection, &SetSelection) {
+	Items(this, &TCustomTreeView::getItems, &TCustomTreeView::SetTreeNodes),
+	Images(this, &TCustomTreeView::getImages, &TCustomTreeView::SetImages),
+	StateImages(this, &TCustomTreeView::getStateImages, &TCustomTreeView::SetStateImages),
+	Selected(this, &TCustomTreeView::GetSelection, &TCustomTreeView::SetSelection) {
 	init(AOwner);
 }
 
 
 TCustomTreeView::TCustomTreeView(GtkWidget *parent) :
 	TWinControl(parent),
-	Images(this, &getImages, &SetImages),
-	StateImages(this, &getStateImages, &SetStateImages),
-	Items(this, &getItems, &SetTreeNodes),
-	Selected(this, &GetSelection, &SetSelection) {
+	Items(this, &TCustomTreeView::getItems, &TCustomTreeView::SetTreeNodes),
+	Images(this, &TCustomTreeView::getImages, &TCustomTreeView::SetImages),
+	StateImages(this, &TCustomTreeView::getStateImages, &TCustomTreeView::SetStateImages),
+	Selected(this, &TCustomTreeView::GetSelection, &TCustomTreeView::SetSelection) {
 	nativeControl = gtk_tree_new();
 /*
   gtk_widget_ref (nativeControl);
