@@ -6,11 +6,11 @@
 
 
 TTreeNode::TTreeNode(TTreeNodes *AOwner) :
-	Text(this, &getText, &SetText),
-	StateIndex(this, &getStateIndex, &SetStateIndex),
-	ImageIndex(this, &getImageIndex, &SetImageIndex),
-	Data(this, &getData, &SetData),
-	Parent(this, &GetParent, 0) {
+	Text(this, &TTreeNode::getText, &TTreeNode::SetText),
+	StateIndex(this, &TTreeNode::getStateIndex, &TTreeNode::SetStateIndex),
+	ImageIndex(this, &TTreeNode::getImageIndex, &TTreeNode::SetImageIndex),
+	Data(this, &TTreeNode::getData, &TTreeNode::SetData),
+	Parent(this, &TTreeNode::GetParent, 0) {
 	FOwner = AOwner;
 	FStateIndex = 0;
 	FImageIndex = 0;
@@ -18,11 +18,11 @@ TTreeNode::TTreeNode(TTreeNodes *AOwner) :
 
 
 TTreeNode::TTreeNode(const TTreeNode &other) :
-	Text(this, &getText, &SetText),
-	StateIndex(this, &getStateIndex, &SetStateIndex),
-	ImageIndex(this, &getImageIndex, &SetImageIndex),
-	Data(this, &getData, &SetData),
-	Parent(this, &GetParent, 0) {
+	Text(this, &TTreeNode::getText, &TTreeNode::SetText),
+	StateIndex(this, &TTreeNode::getStateIndex, &TTreeNode::SetStateIndex),
+	ImageIndex(this, &TTreeNode::getImageIndex, &TTreeNode::SetImageIndex),
+	Data(this, &TTreeNode::getData, &TTreeNode::SetData),
+	Parent(this, &TTreeNode::GetParent, 0) {
 	FOwner = other.FOwner;
 	subTreeOwner = other.subTreeOwner;
 	nativeControl = other.nativeControl;
@@ -33,11 +33,11 @@ TTreeNode::TTreeNode(const TTreeNode &other) :
 }
 
 TTreeNode::TTreeNode(TTreeNodes *AOwner, GtkTree *AsubTreeOwner, GtkTreeItem *AnativeControl, string AText, void *Ptr) : 
-	Text(this, &getText, &SetText),
-	StateIndex(this, &getStateIndex, &SetStateIndex),
-	ImageIndex(this, &getImageIndex, &SetImageIndex),
-	Data(this, &getData, &SetData),
-	Parent(this, &GetParent, 0) {
+	Text(this, &TTreeNode::getText, &TTreeNode::SetText),
+	StateIndex(this, &TTreeNode::getStateIndex, &TTreeNode::SetStateIndex),
+	ImageIndex(this, &TTreeNode::getImageIndex, &TTreeNode::SetImageIndex),
+	Data(this, &TTreeNode::getData, &TTreeNode::SetData),
+	Parent(this, &TTreeNode::GetParent, 0) {
 	FOwner = AOwner;
 	subTreeOwner = AsubTreeOwner;
 	nativeControl = AnativeControl;
