@@ -4,7 +4,7 @@
  *				(e.g. verse, word,
  *				place, etc.)
  *
- * $Id: listkey.h,v 1.1.1.1 1999/05/04 22:03:36 scribe Exp $
+ * $Id: listkey.h,v 1.3 2000/11/05 12:31:59 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -44,14 +44,17 @@ public:
 	virtual int Count();
 	virtual void Remove();	// remove current element
 	virtual char SetToElement(int, POSITION = TOP);
+	virtual SWKey *GetElement(int pos = -1);
 	virtual ListKey &operator <<(const SWKey &); // add to list
-	virtual ListKey &operator =(ListKey &ikey);
+	virtual ListKey &operator =(const ListKey &ikey);
 	virtual SWKey &operator =(const char *ikey){ return SWKey::operator =(ikey); }
 	virtual SWKey &operator =(const SWKey &ikey){ return SWKey::operator =(ikey); }
 	virtual SWKey &operator =(POSITION);
 	virtual SWKey &operator -=(int decrement);
 	virtual SWKey &operator +=(int increment);
 	virtual char Traversable() { return 1; }
+	virtual long Index() const { return arraypos; }
+	virtual long Index(long iindex) { SetToElement(arraypos); return Index(); }
 };
 
 
