@@ -2,7 +2,7 @@
  *  swmgr.h   - definition of class SWMgr used to interact with an install
  *				base of sword modules.
  *
- * $Id: swmgr.h,v 1.9 2000/03/12 23:12:32 scribe Exp $
+ * $Id: swmgr.h,v 1.17 2000/11/06 12:47:10 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -23,8 +23,10 @@
 #ifndef SWMGR_H
 #define SWMGR_H
 
+#include <sys/types.h>
 #include <string>
 #include <map>
+#include <list>
 #include <swmodule.h>
 #include <swconfig.h>
 #include <swlog.h>
@@ -36,17 +38,17 @@ typedef list<string> OptionsList;
 typedef map <string, SWFilter *> FilterMap;
 
 class SWMgr {
-private:
-	SWConfig *myconfig;
-	SWConfig *mysysconfig;
-
-	void SWMgr::CreateMods();
-	SWModule *SWMgr::CreateMod(string name, string driver, ConfigEntMap &section);
-	void SWMgr::DeleteMods();
-	char configType;	// 0 = file; 1 = directory
+private:	
 
 protected:
+	SWConfig *myconfig;	//made protected because because BibleTime needs it
+	SWConfig *mysysconfig;
+	void CreateMods();
+	SWModule *CreateMod(string name, string driver, ConfigEntMap &section);
+	void DeleteMods();
+	char configType;	// 0 = file; 1 = directory
 	FilterMap optionFilters;
+	FilterMap cipherFilters;
 	SWFilter *gbfplain;
 	FilterList cleanupFilters;
 	OptionsList options;
@@ -60,6 +62,7 @@ protected:
 	virtual void AddRawFilters(SWModule *module, ConfigEntMap &section);
 
 public:
+	static bool debug;
 	static void findConfig(char *configType, char **prefixPath, char **configPath);
 	static char existsFile(const char *ipath, const char *ifileName);
 	static char existsDir(const char *ipath, const char *idirName);
@@ -80,5 +83,6 @@ public:
 	virtual const char *getGlobalOptionTip(const char *option);
 	virtual OptionsList getGlobalOptions();
 	virtual OptionsList getGlobalOptionValues(const char *option);
+	virtual char setCipherKey(const char *modName, const char *key);
 };
 #endif
