@@ -1,7 +1,7 @@
 /****************************************************************************** 
  *  versekey.h - code for class 'versekey'- a standard Biblical verse key
  *
- * $Id: versekey.h,v 1.3 2000/03/13 09:36:02 scribe Exp $
+ * $Id: versekey.h,v 1.8 2000/10/29 22:43:37 jansorg Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -30,9 +30,11 @@
 
 #define POS_MAXVERSE ((char)3)
 #define POS_MAXCHAPTER ((char)4)
+#define POS_MAXBOOK ((char)5)
 
 #define MAXVERSE POSITION(POS_MAXVERSE)
 #define MAXCHAPTER POSITION(POS_MAXCHAPTER)
+#define MAXBOOK POSITION(POS_MAXBOOK)
 
 struct sbook {
 	const char *name;		// Name of book
@@ -45,7 +47,25 @@ struct abbrev {
 	int book;
 };
 
+
+class SWLocale;
+
 class VerseKey : public SWKey {
+	class LocaleCache {
+	public:
+		char *name;
+		unsigned int abbrevsCnt;
+		SWLocale *locale;
+		LocaleCache() {
+			name = 0;
+			abbrevsCnt = 0;
+			locale = 0;
+		}
+		~LocaleCache() {
+			if (name)
+				delete [] name;
+		}
+	};
 
 	static long *offsets[2][2];
 	static int offsize[2][2];
@@ -57,7 +77,8 @@ class VerseKey : public SWKey {
 	static long ntbks[];
 	static long ntcps[];
 	static int vm[];
-	static ListKey internalListKey;
+	static LocaleCache localeCache;
+	ListKey internalListKey;
 
 	const struct abbrev *abbrevs;
 	int abbrevsCnt;
@@ -120,13 +141,14 @@ public:
 	virtual void Normalize(char autocheck = 0);
 	virtual char AutoNormalize(char iautonorm = MAXPOS(char));
 	virtual char Headings(char iheadings = MAXPOS(char));
+	virtual long NewIndex() const;
 	virtual long Index() const;
 	virtual long Index(long iindex);
 
-	virtual ListKey &ParseVerseList(char *buf, const char *defaultKey = "Genesis 1:1", char max = 0);
+	virtual ListKey ParseVerseList(const char *buf, const char *defaultKey = "Genesis 1:1", bool expandRange = false);
 	virtual int compare(const SWKey &ikey);
 	virtual int _compare(const VerseKey &ikey);
-	virtual void setBookAbbrevs(const struct abbrev *bookAbbrevs);
+	virtual void setBookAbbrevs(const struct abbrev *bookAbbrevs, unsigned int size = 0 /* default determine size */);
 	virtual void setBooks(const char *iBMAX, struct sbook **ibooks);
 	virtual void setLocale(const char *name);
 };
