@@ -2,7 +2,7 @@
  *  swmgr.cpp   - implementaion of class SWMgr used to interact with an install
  *				base of sword modules.
  *
- * $Id: swmgr.cpp,v 1.15 2000/03/12 23:12:32 scribe Exp $
+ * $Id: swmgr.cpp,v 1.22 2000/11/06 12:47:10 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -47,8 +47,12 @@
 #include <cipherfil.h>
 #include <rawfiles.h>
 #include <ztext.h>
-#include <zipcomprs.h>
 
+#ifdef ZLIBSUPPORTED
+#include <zipcomprs.h>
+#endif
+
+bool SWMgr::debug = false;
 
 void SWMgr::init() {
 	SWFilter *tmpFilter = 0;
@@ -58,6 +62,7 @@ void SWMgr::init() {
 	myconfig    = 0;
 	mysysconfig = 0;
 
+	cipherFilters.clear();
 	optionFilters.clear();
 	cleanupFilters.clear();
 
@@ -184,13 +189,27 @@ void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath) {
 	*configType = 0;
 
 	// check working directory
+if (debug)
+	cerr << "Checking working directory for mods.conf...";
 
 	if (existsFile(".", "mods.conf")) {
+
+if (debug)
+	cerr << "found\n";
+
 		stdstr(prefixPath, "./");
 		stdstr(configPath, "./mods.conf");
 		return;
 	}
+
+if (debug)
+	cerr << "\nChecking working directory for mods.d...";
+
 	if (existsDir(".", "mods.d")) {
+
+if (debug)
+	cerr << "found\n";
+
 		stdstr(prefixPath, "./");
 		stdstr(configPath, "./mods.d");
 		*configType = 1;
@@ -200,17 +219,41 @@ void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath) {
 
 	// check environment variable SWORD_PATH
 
+if (debug)
+	cerr << "\nChecking SWORD_PATH...";
+
 	if (envsworddir != NULL) {
+
+if (debug)
+	cerr << "found (" << envsworddir << ")\n";
+
 		path = envsworddir;
 		if ((envsworddir[strlen(envsworddir)-1] != '\\') && (envsworddir[strlen(envsworddir)-1] != '/'))
 			path += "/";
+
+if (debug)
+	cerr << "\nChecking $SWORD_PATH for mods.conf...";
+
+
 		if (existsFile(path.c_str(), "mods.conf")) {
+
+if (debug)
+	cerr << "found\n";
+
 			stdstr(prefixPath, path.c_str());
 			path += "mods.conf";
 			stdstr(configPath, path.c_str());
 			return;
 		}
+
+if (debug)
+	cerr << "\nChecking $SWORD_PATH for mods.d...";
+
 		if (existsDir(path.c_str(), "mods.d")) {
+
+if (debug)
+	cerr << "found\n";
+
 			stdstr(prefixPath, path.c_str());
 			path += "mods.d";
 			stdstr(configPath, path.c_str());
@@ -220,52 +263,94 @@ void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath) {
 	}
 
 
+	// check for systemwide /etc/sword.conf
+
+if (debug)
+	cerr << "\nChecking for /etc/sword.conf...";
+
+	if ((fd = ::open("/etc/sword.conf", O_RDONLY)) > 0) {
+		::close(fd);
+
+if (debug)
+	cerr << "found\n";
+
+		SWConfig etcconf("/etc/sword.conf");
+		if ((entry = etcconf.Sections["Install"].find("DataPath")) != etcconf.Sections["Install"].end()) {
+			path = (*entry).second;
+			if (((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '\\') && ((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '/'))
+				path += "/";
+
+if (debug)
+	cerr << "DataPath in /etc/sword.conf is set to: " << path;
+
+if (debug)
+	cerr << "\nChecking for mods.conf in DataPath ";
+
+			if (existsFile(path.c_str(), "mods.conf")) {
+
+if (debug)
+	cerr << "found\n";
+
+				stdstr(prefixPath, path.c_str());
+				path += "mods.conf";
+				stdstr(configPath, path.c_str());
+				return;
+			}
+
+if (debug)
+	cerr << "\nChecking for mods.d in DataPath ";
+
+			if (existsDir(path.c_str(), "mods.d")) {
+
+if (debug)
+	cerr << "found\n";
+
+				stdstr(prefixPath, path.c_str());
+				path += "mods.d";
+				stdstr(configPath, path.c_str());
+				*configType = 1;
+				return;
+			}
+		}
+	}
+
+
 	// check ~/.sword/
 
+if (debug)
+	cerr << "\nChecking home directory for ~/.sword/mods.conf" << path;
+
 	if (envhomedir != NULL) {
 		path = envhomedir;
 		if ((envhomedir[strlen(envhomedir)-1] != '\\') && (envhomedir[strlen(envhomedir)-1] != '/'))
 			path += "/";
 		path += ".sword/";
 		if (existsFile(path.c_str(), "mods.conf")) {
+
+if (debug)
+	cerr << "found\n";
+
 			stdstr(prefixPath, "");
 			path += "mods.conf";
 			stdstr(configPath, path.c_str());
 			return;
 		}
+
+if (debug)
+	cerr << "\nChecking home directory for ~/.sword/mods.d" << path;
+
 		if (existsDir(path.c_str(), "mods.d")) {
+
+if (debug)
+	cerr << "found\n";
+
 			stdstr(prefixPath, "");
 			path += "mods.d";
 			stdstr(configPath, path.c_str());
-			*configType = 1;
+			*configType = 2;
 			return;
 		}
 	}
-
-
-	if ((fd = ::open("/etc/sword.conf", O_RDONLY)) > 0) {
-		::close(fd);
-		SWConfig etcconf("/etc/sword.conf");
-		if ((entry = etcconf.Sections["Install"].find("DataPath")) != etcconf.Sections["Install"].end()) {
-			path = (*entry).second;
-			if (((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '\\') && ((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '/'))
-				path += "/";
-
-			if (existsFile(path.c_str(), "mods.conf")) {
-				stdstr(prefixPath, path.c_str());
-				path += "mods.conf";
-				stdstr(configPath, path.c_str());
-				return;
-			}
-			if (existsDir(path.c_str(), "mods.d")) {
-				stdstr(prefixPath, path.c_str());
-				path += "mods.d";
-				stdstr(configPath, path.c_str());
-				*configType = 1;
-				return;
-			}
-		}
-	}
 }
 
 
@@ -330,8 +415,41 @@ void SWMgr::Load() {
 		}
 		else	config->Load();
 
-
 		CreateMods();
+
+//	augment config with ~/.sword/mods.d if it exists ---------------------
+			char *envhomedir  = getenv ("HOME");
+			if (envhomedir != NULL && configType != 2) { // 2 = user only
+				string path = envhomedir;
+				if ((envhomedir[strlen(envhomedir)-1] != '\\') && (envhomedir[strlen(envhomedir)-1] != '/'))
+					path += "/";
+				path += ".sword/";
+				if (existsDir(path.c_str(), "mods.d")) {
+					char *savePrefixPath = 0;
+					char *saveConfigPath = 0;
+					SWConfig *saveConfig = 0;
+					stdstr(&savePrefixPath, prefixPath);
+					stdstr(&prefixPath, path.c_str());
+					path += "mods.d";
+					stdstr(&saveConfigPath, configPath);
+					stdstr(&configPath, path.c_str());
+					saveConfig = config;
+					config = myconfig = 0;
+					loadConfigDir(configPath);
+
+					CreateMods();
+
+					stdstr(&prefixPath, savePrefixPath);
+					delete []savePrefixPath;
+					stdstr(&configPath, saveConfigPath);
+					delete []saveConfigPath;
+					(*saveConfig) += *config;
+					delete myconfig;
+					config = myconfig = saveConfig;
+				}
+			}
+// -------------------------------------------------------------------------
+
 	}
 	else {
 		SWLog::systemlog->LogError("SWMgr: Can't find 'mods.conf' or 'mods.d'.  Try setting:\n\tSWORD_PATH=<directory containing mods.conf>\n\tOr see the README file for a full description of setup options (%s)", (configPath) ? configPath : "<configPath is null>");
@@ -354,14 +472,17 @@ SWModule *SWMgr::CreateMod(string name, string driver, ConfigEntMap &section)
 	char *buf = new char [ strlen(misc1.c_str()) + 1 ];
 	char *buf2 = buf;
 	strcpy(buf, misc1.c_str());
-	for (; ((*buf2) && ((*buf2 == '.') || (*buf2 == '/') || (*buf2 == '\\'))); buf2++);
+//	for (; ((*buf2) && ((*buf2 == '.') || (*buf2 == '/') || (*buf2 == '\\'))); buf2++);
+	for (; ((*buf2) && ((*buf2 == '/') || (*buf2 == '\\'))); buf2++);
 	if (*buf2)
 		datapath += buf2;
 	delete [] buf;
 	
+#ifdef ZLIBSUPPORTED
 	if (!stricmp(driver.c_str(), "zText")) {
 		newmod = new zText(datapath.c_str(), name.c_str(), description.c_str(), zVerse::CHAPTERBLOCKS, new ZipCompress());
 	}
+#endif
 	
 	if (!stricmp(driver.c_str(), "RawText")) {
 		newmod = new RawText(datapath.c_str(), name.c_str(), description.c_str());
@@ -426,6 +547,7 @@ void SWMgr::AddRawFilters(SWModule *module, ConfigEntMap &section) {
 	cipherKey = ((entry = section.find("CipherKey")) != section.end()) ? (*entry).second : (string)"";
 	if (!cipherKey.empty()) {
 		SWFilter *cipherFilter = new CipherFilter(cipherKey.c_str());
+		cipherFilters.insert(FilterMap::value_type(module->Name(), cipherFilter));
 		cleanupFilters.push_back(cipherFilter);
 		module->AddRawFilter(cipherFilter);
 	}
@@ -628,3 +750,26 @@ OptionsList SWMgr::getGlobalOptionValues(const char *option)
 }
 
 
+char SWMgr::setCipherKey(const char *modName, const char *key) {
+	FilterMap::iterator it;
+	ModMap::iterator it2;
+
+	// check for filter that already exists
+	it = cipherFilters.find(modName);
+	if (it != cipherFilters.end()) {
+		((CipherFilter *)(*it).second)->getCipher()->setCipherKey(key);
+		return 0;
+	}
+	// check if module exists
+	else {
+		it2 = Modules.find(modName);
+		if (it2 != Modules.end()) {
+			SWFilter *cipherFilter = new CipherFilter(key);
+			cipherFilters.insert(FilterMap::value_type(modName, cipherFilter));
+			cleanupFilters.push_back(cipherFilter);
+			(*it2).second->AddRawFilter(cipherFilter);
+			return 0;
+		}
+	}
+	return -1;
+}
